LoadOptions

Struct LoadOptions 

pub struct LoadOptions {
    pub state_dir: Option<PathBuf>,
    pub state_file_name: Option<String>,
    pub state_path: Option<PathBuf>,
    pub host_filesystem_prefix: Option<PathBuf>,
    pub monotonic_now: Option<Arc<dyn Fn() -> Result<u64> + Send + Sync>>,
    pub monotonic_label: Option<String>,
}
Configures local-host helper loading.

The zero value uses platform defaults. State paths are used only on Windows and on FreeBSD when native kern.boot_id is unavailable.

Fields

state_dir: Option<PathBuf>state_file_name: Option<String>state_path: Option<PathBuf>host_filesystem_prefix: Option<PathBuf>monotonic_now: Option<Arc<dyn Fn() -> Result<u64> + Send + Sync>>monotonic_label: Option<String>

Implementations

Source

impl LoadOptions

pub fn with_state_dir(self, path: impl Into<PathBuf>) -> Self

pub fn with_state_file_name(self, name: impl Into<String>) -> Self

pub fn with_state_path(self, path: impl Into<PathBuf>) -> Self

pub fn with_host_filesystem_prefix(self, path: impl Into<PathBuf>) -> Self

Resolves Linux host identity from a mounted host filesystem prefix.

This is opt-in. When set on Linux, machine-id resolution checks <prefix>/etc/machine-id and <prefix>/var/lib/dbus/machine-id before the container-local paths, and boot-id resolution checks <prefix>/proc/sys/kernel/random/boot_id before the container-local path.

pub fn with_monotonic_now( self, label: impl Into<String>, source: Arc<dyn Fn() -> Result<u64> + Send + Sync>, ) -> Self